Package: gdalcubes
Title: Earth Observation Data Cubes from Satellite Image Collections
Version: 0.6.0
Date: 2022-03-07
Authors@R: c(
    person(given = "Marius",
           family = "Appel",
           role = c("aut", "cre"),
           email = "marius.appel@uni-muenster.de",
           comment = c(ORCID = "0000-0001-5281-3896")),
    person(given = "Edzer",
           family = "Pebesma",
           role = "ctb",
           comment = c(ORCID = "0000-0001-8049-7069")),
    person(given = "Roger",
           family = "Bivand",
           role = "ctb"),
    person(given = "Jeroen",
           family = "Ooms",
           role = "ctb",
           comment = c(ORCID = "0000-0002-4035-0289")),        
    person(given = "Lewis",
           family = "Van Winkle",
           role = "cph"),
    person(given = "Ole Christian",
           family = "Eidheim",
           role = "cph"),
    person(given = "Howard",
           family = "Hinnant",
           role = "cph"),
    person(given = "Adrian",
           family = "Colomitchi",
           role = "cph"),
    person(given = "Florian",
           family = "Dang",
           role = "cph"),
    person(given = "Paul",
           family = "Thompson",
           role = "cph"),
    person(given = "Tomasz",
           family = "Kamiński",
           role = "cph"),
    person(given = "Dropbox, Inc.",
           role = "cph"))
Description: Processing collections of Earth observation images as on-demand multispectral, multitemporal raster data cubes. Users
    define cubes by spatiotemporal extent, resolution, and spatial reference system and let 'gdalcubes' automatically apply cropping, reprojection, and 
    resampling using the 'Geospatial Data Abstraction Library' ('GDAL'). Implemented functions on data cubes include reduction over space and time, 
    applying arithmetic expressions on pixel band values, moving window aggregates over time, filtering by space, time, bands, and predicates on pixel values, 
    exporting data cubes as 'netCDF' or 'GeoTIFF' files, plotting, and extraction from spatial and or spatiotemporal features.  
    All computational parts are implemented in C++, linking to the 'GDAL', 'netCDF', 'CURL', and 'SQLite' libraries. 
    See Appel and Pebesma (2019) <doi:10.3390/data4030092> for further details.
Depends: R (>= 3.4)
Imports: Rcpp, jsonlite, ncdf4
License: MIT + file LICENSE
URL: https://github.com/appelmar/gdalcubes_R
BugReports: https://github.com/appelmar/gdalcubes_R/issues/
Encoding: UTF-8
RoxygenNote: 7.1.2
LinkingTo: Rcpp
Suggests: knitr, magrittr, rmarkdown, stars, av, gifski, sf, tinytest
VignetteBuilder: knitr
Copyright: file inst/COPYRIGHTS
NeedsCompilation: yes
SystemRequirements: cxx11, gdal, libgdal, libproj, netcdf4
Packaged: 2022-03-07 13:07:50 UTC; marius
Author: Marius Appel [aut, cre] (<https://orcid.org/0000-0001-5281-3896>),
  Edzer Pebesma [ctb] (<https://orcid.org/0000-0001-8049-7069>),
  Roger Bivand [ctb],
  Jeroen Ooms [ctb] (<https://orcid.org/0000-0002-4035-0289>),
  Lewis Van Winkle [cph],
  Ole Christian Eidheim [cph],
  Howard Hinnant [cph],
  Adrian Colomitchi [cph],
  Florian Dang [cph],
  Paul Thompson [cph],
  Tomasz Kamiński [cph],
  Dropbox, Inc. [cph]
Maintainer: Marius Appel <marius.appel@uni-muenster.de>
Repository: CRAN
Date/Publication: 2022-03-08 08:40:21 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2022-04-22 06:41:59 UTC; windows
Archs: x64
